Rent

Struct Rent 

#[repr(C)]
pub struct Rent { pub lamports_per_byte: u64, pub exemption_threshold: [u8; 8], pub burn_percent: u8, }
Configuration of network rent.

Fields

lamports_per_byte: u64

Rental rate in lamports/byte.

exemption_threshold: [u8; 8]
👎Deprecated since 4.1.0:

Use Rent::minimum_balance() directly

Formerly, the amount of time (in years) a balance must include rent for the account to be rent exempt. Now it’s just empty space.

burn_percent: u8
👎Deprecated since 4.1.0:

Rent no longer exists

Formerly, the percentage of collected rent that is burned.

Implementations

Source

impl Rent

pub fn minimum_balance(&self, data_len: usize) -> u64

Calculates the minimum balance for rent exemption.

This method avoids floating-point operations when the exemption_threshold is the default value.

Arguments
  • data_len - The number of bytes in the account
Returns

The minimum balance in lamports for rent exemption.

Panics

Panics if data_len exceeds the maximum permitted data length or if the lamports_per_byte is too large based on the exemption_threshold.

pub fn minimum_balance_unchecked(&self, data_len: usize) -> u64

Calculates the minimum balance for rent exemption without performing any validation.

This method avoids floating-point operations when the exemption_threshold is the default value.

Important

The caller must ensure that data_len is within the permitted limit and the lamports_per_byte is within the permitted limit based on the exemption_threshold to avoid overflow.

Arguments
  • data_len - The number of bytes in the account
Returns

The minimum balance in lamports for rent exemption.

pub fn try_minimum_balance(&self, data_len: usize) -> Option<u64>

Calculates the minimum balance for rent exemption.

This method avoids floating-point operations when the exemption_threshold is the default value.

Arguments
  • data_len - The number of bytes in the account
Returns
  • Some(u64) - The minimum balance in lamports for rent exemption, if all checks pass.
  • None - If data_len exceeds the maximum permitted data length, or if the lamports_per_byte is too large based on the exemption_threshold, which would cause an overflow.
pub fn is_exempt(&self, balance: u64, data_len: usize) -> bool

Whether a given balance and data length would be exempt.

pub fn free() -> Rent

Creates a Rent that charges no lamports.

This is used for testing.

pub fn with_lamports_per_byte(lamports_per_byte: u64) -> Rent

Creates a Rent with lamports per byte