Module cpi

Module cpi 

Cross-Program Invocation (CPI) error types

Structs

CallerAccount
Host side representation of AccountInfo or SolAccountInfo passed to the CPI syscall.
TranslatedAccount
Account data and metadata that has been translated from caller space.

Enums

CpiError
CPI-specific error types

Traits

SyscallInvokeSigned
Implemented by language specific data structure translators

Functions

cpi_common
Call process instruction, common to both Rust and C
translate_accounts_c
translate_accounts_rust
translate_instruction_c
translate_instruction_rust
translate_signers