pub enum CpiError {
InvalidPointer,
TooManySigners,
BadSeeds(PubkeyError),
InvalidLength,
MaxInstructionAccountsExceeded {
num_accounts: u64,
max_accounts: u64,
},
MaxInstructionDataLenExceeded {
data_len: u64,
max_data_len: u64,
},
MaxInstructionAccountInfosExceeded {
num_account_infos: u64,
max_account_infos: u64,
},
ProgramNotSupported(Pubkey),
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
CPI-specific error types
Variants
InvalidPointer
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
TooManySigners
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
BadSeeds(PubkeyError)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
InvalidLength
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
MaxInstructionAccountsExceeded
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
MaxInstructionDataLenExceeded
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
MaxInstructionAccountInfosExceeded
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
ProgramNotSupported(Pubkey)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.