pub struct CallerAccount<'a> {
pub lamports: &'a mut u64,
pub owner: &'a mut Pubkey,
pub original_data_len: usize,
pub serialized_data: &'a mut [u8],
pub vm_data_addr: u64,
pub ref_to_len_in_vm: &'a mut u64,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Host side representation of AccountInfo or SolAccountInfo passed to the CPI syscall.
At the start of a CPI, this can be different from the data stored in the corresponding BorrowedAccount, and needs to be synched.
Fields
lamports: &'a mut u64This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
owner: &'a mut PubkeyThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
original_data_len: usizeThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
serialized_data: &'a mut [u8]This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
vm_data_addr: u64This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
ref_to_len_in_vm: &'a mut u64This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Implementations
Sourceimpl<'a> CallerAccount<'a>
impl<'a> CallerAccount<'a>
pub fn get_serialized_data( memory_mapping: &MemoryMapping<'_>, vm_addr: u64, len: u64, stricter_abi_and_runtime_constraints: bool, account_data_direct_mapping: bool, ) -> Result<&'a mut [u8], Box<dyn Error>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn from_account_info( invoke_context: &InvokeContext<'_, '_>, memory_mapping: &MemoryMapping<'_>, check_aligned: bool, _vm_addr: u64, account_info: &AccountInfo<'_>, account_metadata: &SerializedAccountMetadata, ) -> Result<CallerAccount<'a>, Box<dyn Error>>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.