pub struct SVMTransactionExecutionAndFeeBudgetLimits {
pub budget: SVMTransactionExecutionBudget,
pub loaded_accounts_data_size_limit: NonZeroU32,
pub fee_details: FeeDetails,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
budget: SVMTransactionExecutionBudgetThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
loaded_accounts_data_size_limit: NonZeroU32This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
fee_details: FeeDetailsThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.