pub struct EnvironmentConfig<'a> {
pub blockhash: Hash,
pub blockhash_lamports_per_signature: u64,
pub program_runtime_environments_for_execution: &'a ProgramRuntimeEnvironments,
pub program_runtime_environments_for_deployment: &'a ProgramRuntimeEnvironments,
/* private fields */
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
blockhash: HashThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
blockhash_lamports_per_signature: u64This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
program_runtime_environments_for_execution: &'a ProgramRuntimeEnvironmentsThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
program_runtime_environments_for_deployment: &'a ProgramRuntimeEnvironmentsThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Implementations
Sourceimpl<'a> EnvironmentConfig<'a>
impl<'a> EnvironmentConfig<'a>
pub fn new( blockhash: Hash, blockhash_lamports_per_signature: u64, epoch_stake_callback: &'a dyn InvokeContextCallback, feature_set: &'a SVMFeatureSet, program_runtime_environments_for_execution: &'a ProgramRuntimeEnvironments, program_runtime_environments_for_deployment: &'a ProgramRuntimeEnvironments, sysvar_cache: &'a SysvarCache, ) -> Self
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.