Module loaded_programs

Module loaded_programs 

Structs

EpochBoundaryPreparation
Globally manages the transition between environments at the epoch boundary
ProgramCache
This structure is the global cache of loaded, verified and compiled programs.
ProgramCacheForTxBatch
Local view into ProgramCache which was extracted for a specific TX batch.
ProgramRuntimeEnvironment
ProgramRuntimeEnvironments
Paired execution and deployment environments.
ProgramToLoad
Input of ProgramCache::extract()

Enums

BlockRelation
Relationship between two fork IDs
ProgramCacheMatchCriteria

Constants

MAX_LOADED_ENTRY_COUNT

Traits

ForkGraph
Maps relationship between two slots.

Functions

get_mock_program_runtime_environment