pub struct ProgramCacheForTxBatch {
pub hit_max_limit: bool,
pub loaded_missing: bool,
pub merged_modified: bool,
/* private fields */
}Expand description
Local view into ProgramCache which was extracted for a specific TX batch.
This isolation enables the global ProgramCache to continue to evolve (e.g. evictions), while the TX batch is guaranteed it will continue to find all the programs it requires. For program management instructions this also buffers them before they are merged back into the global ProgramCache.
Fields
hit_max_limit: boolloaded_missing: boolmerged_modified: boolImplementations
Sourceimpl ProgramCacheForTxBatch
impl ProgramCacheForTxBatch
pub fn new(slot: Slot) -> Self
Sourcepub fn replenish(
&mut self,
key: Pubkey,
entry: Arc<ProgramCacheEntry>,
) -> (bool, Arc<ProgramCacheEntry>)
pub fn replenish( &mut self, key: Pubkey, entry: Arc<ProgramCacheEntry>, ) -> (bool, Arc<ProgramCacheEntry>)
Refill the cache with a single entry. It’s typically called during transaction loading, and
transaction processing (for program management instructions).
It replaces the existing entry (if any) with the provided entry. The return value contains
true if an entry existed.
The function also returns the newly inserted value.
Sourcepub fn store_modified_entry(
&mut self,
key: Pubkey,
entry: Arc<ProgramCacheEntry>,
)
pub fn store_modified_entry( &mut self, key: Pubkey, entry: Arc<ProgramCacheEntry>, )
Store an entry in modified_entries for a program modified during the
transaction batch.
Sourcepub fn drain_modified_entries(
&mut self,
) -> HashMap<Pubkey, Arc<ProgramCacheEntry>>
pub fn drain_modified_entries( &mut self, ) -> HashMap<Pubkey, Arc<ProgramCacheEntry>>
Drain the program cache’s modified entries, returning the owned collection.
pub fn find(&self, key: &Pubkey) -> Option<Arc<ProgramCacheEntry>>
pub fn slot(&self) -> Slot
pub fn set_slot_for_tests(&mut self, slot: Slot)
pub fn merge( &mut self, modified_entries: &HashMap<Pubkey, Arc<ProgramCacheEntry>>, )
pub fn is_empty(&self) -> bool