pub struct ProgramRuntimeEnvironments {
pub program_runtime_v1: ProgramRuntimeEnvironment,
pub program_runtime_v2: ProgramRuntimeEnvironment,
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Globally shared RBPF config and syscall registry
This is only valid in an epoch range as long as no feature affecting RBPF is activated.
Fields
program_runtime_v1: ProgramRuntimeEnvironmentThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
For program runtime V1
program_runtime_v2: ProgramRuntimeEnvironmentThis crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
For program runtime V2