WorkingSlot

Trait WorkingSlot 

pub trait WorkingSlot {
    // Required methods
    fn current_slot(&self) -> Slot;
    fn is_ancestor(&self, other: Slot) -> bool;
}
Provides information about current working slot, and its ancestors

Required Methods

fn current_slot(&self) -> Slot

Returns the current slot value

fn is_ancestor(&self, other: Slot) -> bool

Returns true if the other slot is an ancestor of self, false otherwise

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors