Module memory

Module memory 

Memory translation utilities.

Enums

MemoryTranslationError
Error types for memory translation operations.

Functions

address_is_aligned
translate_slice
translate_slice_mut_for_cpi
CPI-specific version with intentionally different lifetime signature. This version is missing lifetime ’a of the return type in the parameter &MemoryMapping.
translate_type
translate_type_mut_for_cpi
CPI-specific version with intentionally different lifetime signature. This version is missing lifetime ’a of the return type in the parameter &MemoryMapping.
translate_vm_slice