translate_slice_mut_for_cpi

Function translate_slice_mut_for_cpi 

pub unsafe fn translate_slice_mut_for_cpi<'a, T>(
    memory_mapping: &MemoryMapping,
    vm_addr: u64,
    len: u64,
    check_aligned: bool,
) -> Result<&'a mut [T], Box<dyn Error>>
CPI-specific version with intentionally different lifetime signature. This version is missing lifetime ’a of the return type in the parameter &MemoryMapping.

Safety

  • The caller must ensure that this function does not violate mutable reference uniqueness constraints;
  • The caller must ensure that the lifetime of the returned slice does not outlive the backing data.