Module memory_context

Module memory_context 

Structs

MemoryContext
This structure contains metadata about the memory for each instruction under execution. The BpfAllocator, accounts addresses in the guest and the memory mapping.
MemoryContexts
SerializedAccountMetadata