Module program_cache_entry

Module program_cache_entry 

Structs

ProgramCacheEntry
Holds a program version at a specific address and on a specific slot / fork.

Enums

ProgramCacheEntryOwner
The owner of a programs accounts, thus the loader of a program
ProgramCacheEntryType
Actual payload of ProgramCacheEntry.

Constants

DELAY_VISIBILITY_SLOT_OFFSET