pub struct ProgramCacheEntry {
pub program: ProgramCacheEntryType,
pub account_owner: ProgramCacheEntryOwner,
pub account_size: usize,
pub deployment_slot: Slot,
pub effective_slot: Slot,
pub stats: Arc<ProgramStatistics>,
pub latest_access_slot: AtomicU64,
}Expand description
Holds a program version at a specific address and on a specific slot / fork.
It contains the actual program in ProgramCacheEntryType and a bunch of meta-data.
Fields
program: ProgramCacheEntryTypeThe program of this entry
account_owner: ProgramCacheEntryOwnerThe loader of this entry
account_size: usizeSize of account that stores the program and program data
deployment_slot: SlotSlot in which the program was (re)deployed
effective_slot: SlotSlot in which this entry will become active (can be in the future)
stats: Arc<ProgramStatistics>How often this entry was used by a transaction
latest_access_slot: AtomicU64Implementations
Sourceimpl ProgramCacheEntry
impl ProgramCacheEntry
Sourcepub fn new(
loader_key: &Pubkey,
program_runtime_environment: ProgramRuntimeEnvironment,
deployment_slot: Slot,
effective_slot: Slot,
elf_bytes: &[u8],
account_size: usize,
metrics: &mut LoadProgramMetrics,
) -> Result<Self, Box<dyn Error>>
pub fn new( loader_key: &Pubkey, program_runtime_environment: ProgramRuntimeEnvironment, deployment_slot: Slot, effective_slot: Slot, elf_bytes: &[u8], account_size: usize, metrics: &mut LoadProgramMetrics, ) -> Result<Self, Box<dyn Error>>
Creates a new user program
Sourcepub unsafe fn reload(
loader_key: &Pubkey,
program_runtime_environment: ProgramRuntimeEnvironment,
deployment_slot: Slot,
effective_slot: Slot,
elf_bytes: &[u8],
account_size: usize,
metrics: &mut LoadProgramMetrics,
) -> Result<Self, Box<dyn Error>>
pub unsafe fn reload( loader_key: &Pubkey, program_runtime_environment: ProgramRuntimeEnvironment, deployment_slot: Slot, effective_slot: Slot, elf_bytes: &[u8], account_size: usize, metrics: &mut LoadProgramMetrics, ) -> Result<Self, Box<dyn Error>>
Reloads a user program, without running the verifier.
Safety
This method is unsafe since it assumes that the program has already been verified. Should
only be called when the program was previously verified and loaded in the cache, but was
unloaded due to inactivity. It should also be checked that the program_runtime_environment
hasn’t changed since it was unloaded.
pub fn to_unloaded(&self) -> Option<Self>
Sourcepub fn new_builtin(
deployment_slot: Slot,
account_size: usize,
register_fn: BuiltinFunctionRegisterer,
) -> Self
pub fn new_builtin( deployment_slot: Slot, account_size: usize, register_fn: BuiltinFunctionRegisterer, ) -> Self
Creates a new built-in program
pub fn new_tombstone( slot: Slot, account_owner: ProgramCacheEntryOwner, reason: ProgramCacheEntryType, ) -> Self
pub fn new_tombstone_with_stats( slot: Slot, account_owner: ProgramCacheEntryOwner, reason: ProgramCacheEntryType, stats: Arc<ProgramStatistics>, ) -> Self
pub fn is_tombstone(&self) -> bool
pub fn update_access_slot(&self, slot: Slot)
Sourcepub fn retention_score(&self) -> u64
pub fn retention_score(&self) -> u64
Compute a retention score.
Eviction uses an adapted GDSF scheme which incorporates frequency, recovery cost (recompilation) and time-based decay.
How hard should we try to retain this entry. Higher number -> retention more likely.
pub fn account_owner(&self) -> Pubkey