#[repr(C)]pub struct Rent {
pub lamports_per_byte: u64,
pub exemption_threshold: [u8; 8],
pub burn_percent: u8,
}Expand description
Configuration of network rent.
Fields
lamports_per_byte: u64Rental rate in lamports/byte.
exemption_threshold: [u8; 8]Use Rent::minimum_balance() directly
Formerly, the amount of time (in years) a balance must include rent for the account to be rent exempt. Now it’s just empty space.
burn_percent: u8Rent no longer exists
Formerly, the percentage of collected rent that is burned.
Implementations
Sourceimpl Rent
impl Rent
Sourcepub fn minimum_balance(&self, data_len: usize) -> u64
pub fn minimum_balance(&self, data_len: usize) -> u64
Calculates the minimum balance for rent exemption.
This method avoids floating-point operations when the exemption_threshold
is the default value.
Arguments
data_len- The number of bytes in the account
Returns
The minimum balance in lamports for rent exemption.
Panics
Panics if data_len exceeds the maximum permitted data length or if the
lamports_per_byte is too large based on the exemption_threshold.
Sourcepub fn minimum_balance_unchecked(&self, data_len: usize) -> u64
pub fn minimum_balance_unchecked(&self, data_len: usize) -> u64
Calculates the minimum balance for rent exemption without performing any validation.
This method avoids floating-point operations when the exemption_threshold
is the default value.
Important
The caller must ensure that data_len is within the permitted limit
and the lamports_per_byte is within the permitted limit based on
the exemption_threshold to avoid overflow.
Arguments
data_len- The number of bytes in the account
Returns
The minimum balance in lamports for rent exemption.
Sourcepub fn try_minimum_balance(&self, data_len: usize) -> Option<u64>
pub fn try_minimum_balance(&self, data_len: usize) -> Option<u64>
Calculates the minimum balance for rent exemption.
This method avoids floating-point operations when the exemption_threshold
is the default value.
Arguments
data_len- The number of bytes in the account
Returns
Some(u64)- The minimum balance in lamports for rent exemption, if all checks pass.None- Ifdata_lenexceeds the maximum permitted data length, or if thelamports_per_byteis too large based on theexemption_threshold, which would cause an overflow.
Sourcepub fn is_exempt(&self, balance: u64, data_len: usize) -> bool
pub fn is_exempt(&self, balance: u64, data_len: usize) -> bool
Whether a given balance and data length would be exempt.
Sourcepub fn with_lamports_per_byte(lamports_per_byte: u64) -> Rent
pub fn with_lamports_per_byte(lamports_per_byte: u64) -> Rent
Creates a Rent with lamports per byte