pub struct TransactionContext<'ix_data> { /* private fields */ }Expand description
Loaded transaction shared between runtime and programs.
This context is valid for the entire duration of a transaction being processed.
Implementations
Sourceimpl<'ix_data> TransactionContext<'ix_data>
impl<'ix_data> TransactionContext<'ix_data>
Sourcepub fn new(
transaction_accounts: Vec<(Address, AccountSharedData)>,
rent: Rent,
instruction_stack_capacity: usize,
instruction_trace_capacity: usize,
number_of_top_level_instructions: usize,
) -> TransactionContext<'ix_data>
pub fn new( transaction_accounts: Vec<(Address, AccountSharedData)>, rent: Rent, instruction_stack_capacity: usize, instruction_trace_capacity: usize, number_of_top_level_instructions: usize, ) -> TransactionContext<'ix_data>
Constructs a new TransactionContext
Sourcepub fn deconstruct_without_keys(
self,
) -> Result<Vec<AccountSharedData>, InstructionError>
pub fn deconstruct_without_keys( self, ) -> Result<Vec<AccountSharedData>, InstructionError>
Used in mock_process_instruction
pub fn accounts(&self) -> &Rc<TransactionAccounts>
Sourcepub fn get_number_of_accounts(&self) -> u16
pub fn get_number_of_accounts(&self) -> u16
Returns the total number of accounts loaded in this Transaction
Sourcepub fn get_key_of_account_at_index(
&self,
index_in_transaction: u16,
) -> Result<&Address, InstructionError>
pub fn get_key_of_account_at_index( &self, index_in_transaction: u16, ) -> Result<&Address, InstructionError>
Searches for an account by its key
Sourcepub fn find_index_of_account(&self, pubkey: &Address) -> Option<u16>
pub fn find_index_of_account(&self, pubkey: &Address) -> Option<u16>
Searches for an account by its key
Sourcepub fn get_instruction_trace_capacity(&self) -> usize
pub fn get_instruction_trace_capacity(&self) -> usize
Gets the max length of the instruction trace
Sourcepub fn get_instruction_trace_length(&self) -> usize
pub fn get_instruction_trace_length(&self) -> usize
Returns the instruction trace length.
Not counting the last empty instruction which is always pre-reserved for the next instruction.
Sourcepub fn get_instruction_context_at_index_in_trace(
&self,
index_in_trace: usize,
) -> Result<InstructionContext<'_, '_>, InstructionError>
pub fn get_instruction_context_at_index_in_trace( &self, index_in_trace: usize, ) -> Result<InstructionContext<'_, '_>, InstructionError>
Gets a view on an instruction by its index in the trace
Sourcepub fn get_instruction_context_at_nesting_level(
&self,
nesting_level: usize,
) -> Result<InstructionContext<'_, '_>, InstructionError>
pub fn get_instruction_context_at_nesting_level( &self, nesting_level: usize, ) -> Result<InstructionContext<'_, '_>, InstructionError>
Gets a view on the instruction by its nesting level in the stack
Sourcepub fn get_instruction_stack_capacity(&self) -> usize
pub fn get_instruction_stack_capacity(&self) -> usize
Gets the max height of the instruction stack
Sourcepub fn get_instruction_stack_height(&self) -> usize
pub fn get_instruction_stack_height(&self) -> usize
Gets instruction stack height, top-level instructions are height
solana_instruction::TRANSACTION_LEVEL_STACK_HEIGHT
Sourcepub fn get_current_instruction_index(&self) -> Result<usize, InstructionError>
pub fn get_current_instruction_index(&self) -> Result<usize, InstructionError>
Returns the index in the instruction trace of the current executing instruction
Sourcepub fn get_current_instruction_context(
&self,
) -> Result<InstructionContext<'_, '_>, InstructionError>
pub fn get_current_instruction_context( &self, ) -> Result<InstructionContext<'_, '_>, InstructionError>
Returns a view on the current instruction
Sourcepub fn get_next_instruction_context(
&self,
) -> Result<InstructionContext<'_, '_>, InstructionError>
pub fn get_next_instruction_context( &self, ) -> Result<InstructionContext<'_, '_>, InstructionError>
Returns a view on the next instruction. This function assumes it has already been
configured with the correct values in prepare_next_instruction or
prepare_next_top_level_instruction
Sourcepub fn configure_instruction_at_index(
&mut self,
instruction_index: usize,
program_index: u16,
instruction_accounts: Vec<InstructionAccount>,
deduplication_map: Vec<u16>,
instruction_data: Cow<'ix_data, [u8]>,
caller_index: Option<u16>,
) -> Result<(), InstructionError>
pub fn configure_instruction_at_index( &mut self, instruction_index: usize, program_index: u16, instruction_accounts: Vec<InstructionAccount>, deduplication_map: Vec<u16>, instruction_data: Cow<'ix_data, [u8]>, caller_index: Option<u16>, ) -> Result<(), InstructionError>
Configures an instruction at a specific index in trace.
Sourcepub fn configure_top_level_instruction_for_tests(
&mut self,
program_index: u16,
instruction_accounts: Vec<InstructionAccount>,
instruction_data: Vec<u8>,
) -> Result<(), InstructionError>
pub fn configure_top_level_instruction_for_tests( &mut self, program_index: u16, instruction_accounts: Vec<InstructionAccount>, instruction_data: Vec<u8>, ) -> Result<(), InstructionError>
A version of configure_top_level_instruction to help creating the deduplication map in tests
Sourcepub fn configure_next_cpi_for_tests(
&mut self,
program_index: u16,
instruction_accounts: Vec<InstructionAccount>,
instruction_data: Vec<u8>,
) -> Result<(), InstructionError>
pub fn configure_next_cpi_for_tests( &mut self, program_index: u16, instruction_accounts: Vec<InstructionAccount>, instruction_data: Vec<u8>, ) -> Result<(), InstructionError>
A helper function to facilitate creating a CPI in tests
Sourcepub fn push(&mut self) -> Result<(), InstructionError>
pub fn push(&mut self) -> Result<(), InstructionError>
Pushes the next instruction
Sourcepub fn pop(&mut self) -> Result<(), InstructionError>
pub fn pop(&mut self) -> Result<(), InstructionError>
Pops the current instruction
Sourcepub fn get_return_data(&self) -> (&Address, &[u8])
pub fn get_return_data(&self) -> (&Address, &[u8])
Gets the return data of the current instruction or any above
Sourcepub fn set_return_data(
&mut self,
program_id: Address,
data: Vec<u8>,
) -> Result<(), InstructionError>
pub fn set_return_data( &mut self, program_id: Address, data: Vec<u8>, ) -> Result<(), InstructionError>
Set the return data of the current instruction
Sourcepub fn access_violation_handler(
&self,
virtual_address_space_adjustments: bool,
account_data_direct_mapping: bool,
) -> Box<dyn Fn(&mut MemoryRegion, u64, AccessType, u64, u64)>
pub fn access_violation_handler( &self, virtual_address_space_adjustments: bool, account_data_direct_mapping: bool, ) -> Box<dyn Fn(&mut MemoryRegion, u64, AccessType, u64, u64)>
Returns a new account data write access handler
Sourcepub fn take_instruction_trace(
&mut self,
) -> (Vec<InstructionFrame>, Vec<Box<[InstructionAccount]>>, Vec<Cow<'_, [u8]>>)
pub fn take_instruction_trace( &mut self, ) -> (Vec<InstructionFrame>, Vec<Box<[InstructionAccount]>>, Vec<Cow<'_, [u8]>>)
Take ownership of the instruction trace
Sourcepub fn number_of_called_instructions_in_trace(&self) -> usize
pub fn number_of_called_instructions_in_trace(&self) -> usize
Called instruction are those that the program runtime has already called into. It encompasses instructions under execution (e.g. all nested CPIs are already called) and finished ones.
Top level instructions that have not yet been executed aren’t considered called.
Sourcepub fn next_top_level_instruction_index(&self) -> usize
pub fn next_top_level_instruction_index(&self) -> usize
Return next top level instruction to execute
Sourcepub fn number_of_cpis_in_trace(&self) -> usize
pub fn number_of_cpis_in_trace(&self) -> usize
Return number of CPIs in instruction trace