Cross-Program Invocation (CPI) error types
Structs
- Caller
Account - Host side representation of AccountInfo or SolAccountInfo passed to the CPI syscall.
- Translated
Account - Account data and metadata that has been translated from caller space.
Enums
- CpiError
- CPI-specific error types
Traits
- Syscall
Invoke Signed - Implemented by language specific data structure translators
Functions
- cpi_
common - Call process instruction, common to both Rust and C
- translate_
accounts_ c - translate_
accounts_ rust - translate_
instruction_ c - translate_
instruction_ rust - translate_
signers