pub fn deploy_program(
log_collector: Option<Rc<RefCell<LogCollector>>>,
load_program_metrics: &mut LoadProgramMetrics,
program_cache_for_tx_batch: &mut ProgramCacheForTxBatch,
program_runtime_environment: ProgramRuntimeEnvironment,
disable_sbpf_v0_v1_v2_deployment: bool,
program_id: &Pubkey,
loader_key: &Pubkey,
account_size: usize,
programdata: &[u8],
deployment_slot: Slot,
) -> Result<(), InstructionError>Expand description
Directly deploy a program using a provided invoke context. This function should only be invoked from the runtime, since it does not provide any account loads or checks.