pub struct ProgramCache<FG: ForkGraph> {
pub latest_root_slot: Slot,
pub stats: ProgramCacheStats,
pub fork_graph: Option<Weak<RwLock<FG>>>,
pub loading_task_waiter: Arc<LoadingTaskWaiter>,
/* private fields */
}Expand description
This structure is the global cache of loaded, verified and compiled programs.
It …
- is validator global and fork graph aware, so it can optimize the commonalities across banks.
- handles the visibility rules of un/re/deployments.
- stores the usage statistics and verification status of each program.
- is elastic and uses a probabilistic eviction strategy based on the usage statistics.
- also keeps the compiled executables around, but only for the most used programs.
- supports various kinds of tombstones to avoid loading programs which can not be loaded.
- cleans up entries on orphan branches when the block store is rerooted.
- supports the cache preparation phase before feature activations which can change cached programs.
- manages the environments of the programs and upcoming environments for the next epoch.
- allows for cooperative loading of TX batches which hit the same missing programs simultaneously.
- enforces that all programs used in a batch are eagerly loaded ahead of execution.
- is not persisted to disk or a snapshot, so it needs to cold start and warm up first.
Fields
latest_root_slot: SlotThe slot of the last rerooting
stats: ProgramCacheStatsStatistics counters
fork_graph: Option<Weak<RwLock<FG>>>Reference to the block store
loading_task_waiter: Arc<LoadingTaskWaiter>Coordinates TX batches waiting for others to complete their task during cooperative loading
Implementations
Sourceimpl<FG: ForkGraph> ProgramCache<FG>
impl<FG: ForkGraph> ProgramCache<FG>
pub fn new(root_slot: Slot) -> Self
pub fn set_fork_graph(&mut self, fork_graph: Weak<RwLock<FG>>)
Sourcepub fn assign_program(
&mut self,
program_runtime_environment: &ProgramRuntimeEnvironment,
key: Pubkey,
_last_modification_slot: Slot,
entry: Arc<ProgramCacheEntry>,
) -> bool
pub fn assign_program( &mut self, program_runtime_environment: &ProgramRuntimeEnvironment, key: Pubkey, _last_modification_slot: Slot, entry: Arc<ProgramCacheEntry>, ) -> bool
Insert a single entry. It’s typically called during transaction loading,
when the cache doesn’t contain the entry corresponding to program key.
pub fn prune_by_deployment_slot(&mut self, slot: Slot)
Sourcepub fn prune(
&mut self,
new_root_slot: Slot,
new_environment: Option<ProgramRuntimeEnvironment>,
fork_graph: &FG,
)
pub fn prune( &mut self, new_root_slot: Slot, new_environment: Option<ProgramRuntimeEnvironment>, fork_graph: &FG, )
Before rerooting the blockstore this removes all superfluous entries
Sourcepub fn extract(
&self,
search_for: &mut Vec<ProgramToLoad<'_>>,
loaded_programs_for_tx_batch: &mut ProgramCacheForTxBatch,
program_runtime_environment_for_execution: &ProgramRuntimeEnvironment,
increment_usage_counter: bool,
count_hits_and_misses: bool,
) -> Option<Pubkey>
pub fn extract( &self, search_for: &mut Vec<ProgramToLoad<'_>>, loaded_programs_for_tx_batch: &mut ProgramCacheForTxBatch, program_runtime_environment_for_execution: &ProgramRuntimeEnvironment, increment_usage_counter: bool, count_hits_and_misses: bool, ) -> Option<Pubkey>
Extracts a subset of the programs relevant to a transaction batch and returns which program accounts the accounts DB needs to load.
Sourcepub fn finish_cooperative_loading_task(
&mut self,
program_runtime_environment: &ProgramRuntimeEnvironment,
current_slot: Slot,
key: Pubkey,
last_modification_slot: Slot,
loaded_program: Arc<ProgramCacheEntry>,
) -> bool
pub fn finish_cooperative_loading_task( &mut self, program_runtime_environment: &ProgramRuntimeEnvironment, current_slot: Slot, key: Pubkey, last_modification_slot: Slot, loaded_program: Arc<ProgramCacheEntry>, ) -> bool
Called by Bank::replenish_program_cache() for each program that is done loading.
pub fn merge( &mut self, program_runtime_environment: &ProgramRuntimeEnvironment, current_slot: Slot, modified_entries: &HashMap<Pubkey, Arc<ProgramCacheEntry>>, )
Sourcepub fn get_flattened_entries(
&self,
) -> Vec<(Pubkey, Slot, Arc<ProgramCacheEntry>)>
pub fn get_flattened_entries( &self, ) -> Vec<(Pubkey, Slot, Arc<ProgramCacheEntry>)>
Returns the list of entries which are verified and compiled.
Sourcepub fn get_flattened_entries_for_tests(
&self,
) -> Vec<(Pubkey, Arc<ProgramCacheEntry>)>
pub fn get_flattened_entries_for_tests( &self, ) -> Vec<(Pubkey, Arc<ProgramCacheEntry>)>
Returns the list of all entries in the cache.
Sourcepub fn get_slot_versions_for_tests(
&self,
key: &Pubkey,
) -> &[Arc<ProgramCacheEntry>]
pub fn get_slot_versions_for_tests( &self, key: &Pubkey, ) -> &[Arc<ProgramCacheEntry>]
Returns the slot versions for the given program id.
Sourcepub fn sort_and_unload(&mut self, shrink_to: PercentageInteger)
pub fn sort_and_unload(&mut self, shrink_to: PercentageInteger)
Unloads programs which were used infrequently
Sourcepub fn evict_using_random_selection(
&mut self,
shrink_to: PercentageInteger,
now: Slot,
)
pub fn evict_using_random_selection( &mut self, shrink_to: PercentageInteger, now: Slot, )
Evicts programs using random selection, choosing the worst scoring program out of the entries sampled.
The eviction is performed enough number of times to reduce the cache usage to the given percentage.
Sourcepub fn remove_programs(&mut self, keys: impl Iterator<Item = Pubkey>)
pub fn remove_programs(&mut self, keys: impl Iterator<Item = Pubkey>)
Removes all the entries at the given keys, if they exist
Sourceimpl<FG: ForkGraph> ProgramCache<FG>
impl<FG: ForkGraph> ProgramCache<FG>
Sourcepub fn output_entry_stats(&self)
pub fn output_entry_stats(&self)
Log per-entry statistics for each entry in the global cache.