pub trait WorkingSlot {
// Required methods
fn current_slot(&self) -> Slot;
fn is_ancestor(&self, other: Slot) -> bool;
}Expand description
Provides information about current working slot, and its ancestors
Required Methods
Sourcefn current_slot(&self) -> Slot
fn current_slot(&self) -> Slot
Returns the current slot value
Sourcefn is_ancestor(&self, other: Slot) -> bool
fn is_ancestor(&self, other: Slot) -> bool
Returns true if the other slot is an ancestor of self, false otherwise
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".